print.aidif: S3 print method for class '"aidif"'.

View source: R/class_functions.R

print.aidifR Documentation

S3 print method for class "aidif".

Description

Prints a compact summary of the estimated robust scaling parameters and, when available, the number of items flagged for DIF and DASB.

Usage

## S3 method for class 'aidif'
print(x, ...)

Arguments

x

An object of class "aidif".

...

Further arguments (currently ignored).

Value

x, invisibly.


aiDIF documentation built on April 22, 2026, 1:10 a.m.