| anchor_weights | R Documentation |
Returns the bi-square weights assigned to each item under each scoring condition. Items with weight near zero are effectively excluded from the robust scaling estimate, indicating likely DIF contamination.
anchor_weights(object)
object |
An |
A data.frame with columns human_weight and
(if AI data were provided) ai_weight. Higher weight means
the item is contributing more to the robust scale estimate.
eg <- make_aidif_eg()
mod <- fit_aidif(eg$human, eg$ai)
anchor_weights(mod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.