View source: R/class_functions.R
| print.aidif | R Documentation |
"aidif".Prints a compact summary of the estimated robust scaling parameters and, when available, the number of items flagged for DIF and DASB.
## S3 method for class 'aidif'
print(x, ...)
x |
An object of class |
... |
Further arguments (currently ignored). |
x, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.